@@ -1,5 +1,7 @@
 #pragma once
 
+#include <sys/types.h>
+#include <netinet/in.h>
 #include <netinet/ip.h>
 #include <netinet/ip6.h>
 
