@@ -1,8 +1,7 @@
 #include <caracal/probe.hpp>
 #include <caracal/protocols.hpp>
 #include <caracal/utilities.hpp>
-#include <catch2/benchmark/catch_benchmark.hpp>
-#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch.hpp>
 #include <sstream>
 
 using caracal::Probe;
@@ -20,7 +19,8 @@ std::string to_string(T x) {
 TEST_CASE("Probe::from_csv") {
   SECTION("IPv4 dotted") {
     Probe probe = Probe::from_csv("0.0.0.0,1,2,3,udp");
-    REQUIRE(to_string(probe) == "udp:1:0.0.0.0:2@3");
+    REQUIRE(to_string(probe) ==
+            "dst_addr=0.0.0.0 src_port=1 dst_port=2 ttl=3 protocol=udp");
     REQUIRE(format_addr(probe.dst_addr) == "0.0.0.0");
     REQUIRE(Probe::from_csv(probe.to_csv()) == probe);
     REQUIRE(probe.dst_addr.s6_addr[3] == 0);
@@ -36,7 +36,8 @@ TEST_CASE("Probe::from_csv") {
   SECTION("IPv4 uint32") {
     // Python: int(ip_address("8.8.4.4"))
     Probe probe = Probe::from_csv("134743044,0010,1000,050,icmp");
-    REQUIRE(to_string(probe) == "icmp:10:8.8.4.4:1000@50");
+    REQUIRE(to_string(probe) ==
+            "dst_addr=8.8.4.4 src_port=10 dst_port=1000 ttl=50 protocol=icmp");
     REQUIRE(format_addr(probe.dst_addr) == "8.8.4.4");
     REQUIRE(Probe::from_csv(probe.to_csv()) == probe);
     REQUIRE(probe.src_port == 10);
@@ -52,7 +53,8 @@ TEST_CASE("Probe::from_csv") {
 
   SECTION("IPv4-mapped IPv6") {
     Probe probe = Probe::from_csv("::ffff:8.8.4.4,10,1000,50,icmp");
-    REQUIRE(to_string(probe) == "icmp:10:8.8.4.4:1000@50");
+    REQUIRE(to_string(probe) ==
+            "dst_addr=8.8.4.4 src_port=10 dst_port=1000 ttl=50 protocol=icmp");
     REQUIRE(format_addr(probe.dst_addr) == "8.8.4.4");
     REQUIRE(Probe::from_csv(probe.to_csv()) == probe);
     REQUIRE(probe.src_port == 10);
@@ -68,7 +70,9 @@ TEST_CASE("Probe::from_csv") {
 
   SECTION("IPv6") {
     Probe probe = Probe::from_csv("2001:4860:4860::8888,10,1000,50,icmp6");
-    REQUIRE(to_string(probe) == "icmp6:10:[2001:4860:4860::8888]:1000@50");
+    REQUIRE(to_string(probe) ==
+            "dst_addr=2001:4860:4860::8888 src_port=10 dst_port=1000 ttl=50 "
+            "protocol=icmp6");
     REQUIRE(format_addr(probe.dst_addr) == "2001:4860:4860::8888");
     REQUIRE(Probe::from_csv(probe.to_csv()) == probe);
     REQUIRE(probe.src_port == 10);
